@@ -1,12 +1,12 @@
 from reprlib import recursive_repr
-from typing import (List,
-                    Optional,
+from typing import (Optional,
+                    Sequence,
+                    Tuple,
                     TypeVar)
 
+from ground.hints import Point
 from reprit.base import generate_repr
 
-from clipping.hints import (Point,
-                            Segment)
 from .enums import OverlapKind
 
 
@@ -27,10 +27,6 @@ class NaryEvent:
     def end(self) -> Point:
         return self.complement.start
 
-    @property
-    def segment(self) -> Segment:
-        return self.start, self.end
-
 
 class BinaryEvent:
     __slots__ = 'is_right_endpoint', 'start', 'complement', 'from_left'
@@ -53,18 +49,12 @@ class BinaryEvent:
 
     @property
     def is_vertical(self) -> bool:
-        start_x, _ = self.start
-        end_x, _ = self.end
-        return start_x == end_x
+        return self.start.x == self.end.x
 
     @property
     def primary(self) -> Optional['BinaryEvent']:
         return self.complement if self.is_right_endpoint else self
 
-    @property
-    def segment(self) -> Segment:
-        return self.start, self.end
-
 
 class MixedEvent(BinaryEvent):
     __slots__ = ('interior_to_left', 'other_interior_to_left', 'is_overlap',
@@ -189,7 +179,7 @@ Event = TypeVar('Event', NaryEvent, BinaryEvent, MixedEvent, ShapedEvent,
                 HoleyEvent)
 
 
-def events_to_connectivity(events: List[BinaryEvent]) -> List[int]:
+def events_to_connectivity(events: Sequence[BinaryEvent]) -> Sequence[int]:
     events_count = len(events)
     result = [0] * events_count
     index = 0
@@ -220,3 +210,7 @@ def events_to_connectivity(events: List[BinaryEvent]) -> List[int]:
             result[left_start_index + 1:left_stop_index + 1] = range(
                     left_start_index, left_stop_index)
     return result
+
+
+def event_to_segment_endpoints(event: Event) -> Tuple[Point, Point]:
+    return event.start, event.end
